import Config

config :slax, Slax.Repo,
  username: System.get_env("PGUSER", "postgres"),
  password: System.get_env("PGPASSWORD", "postgres"),
  hostname: System.get_env("PGHOST", "localhost"),
  database: System.get_env("PGDATABASE", "slax_dev"),
  stacktrace: true,
  show_sensitive_data_on_connection_error: true,
  pool_size: 10

config :slax, SlaxWeb.Endpoint,
  http: [ip: {0, 0, 0, 0}, port: 4000],
  check_origin: false,
  code_reloader: true,
  debug_errors: true,
  secret_key_base: "E3KGuV1FenlF8ZEsLrS07FT2dauJGgGzsetqSfhG2u26Z4Bt0SQqaqpNsgyjhnSo",
  watchers: [
    esbuild: {Esbuild, :install_and_run, [:slax, ~w(--sourcemap=inline --watch)]},
    tailwind: {Tailwind, :install_and_run, [:slax, ~w(--watch)]}
  ]

config :slax, SlaxWeb.Endpoint,
  live_reload: [
    patterns: [
      ~r"priv/static/(?!uploads/).*(js|css|png|jpeg|jpg|gif|svg)$",
      ~r"priv/gettext/.*(po)$",
      ~r"lib/slax_web/(controllers|live|components)/.*(ex|heex)$"
    ]
  ]

config :slax, dev_routes: true

config :testcontainers,
  database_enabled: System.get_env("TESTCONTAINER_DATABASE_ENABLED") in ~w(true 1),
  database_volume: "slax_database"

config :logger, :console, format: "[$level] $message\n"

config :phoenix, :stacktrace_depth, 20

config :phoenix, :plug_init_mode, :runtime

config :phoenix_live_view,
  debug_heex_annotations: true,
  enable_expensive_runtime_checks: true

config :swoosh, :api_client, false
